/**
 * 
 */
package com.cybozu.garoon3.address;

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * アドレス帳の情報を管理するクラスです。アドレスカードの一覧を管理します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AddressBook {
    private List<Integer> cardIds;
    private Map<Integer, AddressCardData> cards = new HashMap<Integer, AddressCardData>();
    
    /***
     * 空なカードリストを持つアドレス帳を作ります
     */
    public AddressBook(){
        this.cardIds =  new ArrayList<Integer>();
    }
    
    /***
     * アドレス帳のカードリストを設置します
     * 
     * @param cardIds : アドレスカードIDの一覧
     */
    public AddressBook(List<Integer> cardIds){
        this.cardIds = cardIds;
    }
    
    /**
     * アドレス帳のカードリストに新カードリストを追加します
     * 
     * @param cardIds : 新カードリスト
     */
    public void addCardIds(List<Integer> cardIds){
        for (Integer cardId : cardIds){
            this.cardIds.add(cardId);
        }
    }

    /***
     * アドレスカードID の一覧をコンソールに出力します。デバッグ用の関数です。
     */
    public void printCardIds(){
        for (Integer cardId : this.cardIds){
            System.out.println(cardId.toString());
        }
    }
    
    /***
     * アドレス帳のカード情報をコンソールに出力します。デバッグ用の関数です。
     */
    public void printCards(){
        for (Map.Entry<Integer, AddressCardData> e : cards.entrySet()){
            AddressCardData cardData = e.getValue();
            cardData.printCardDetails();
            System.out.println("---------------------------------------------------");
        }
    }
    
    /***
     * アドレス帳のカード情報を CSV ファイルに出力します。
     * 
     * @param writer 出力ファイルの writer
     * @throws IOException ファイル入出力エラー 
     */
    public void printCardsToCSV(OutputStreamWriter writer) throws IOException {
        AddressCardData.printCardFormatToCSV(writer);
        
        for (Map.Entry<Integer, AddressCardData> e : cards.entrySet()){
            AddressCardData cardData = e.getValue();
            cardData.printCardToCSV(writer);
        }
    }
    
    /***
     * アドレス帳に一つのカードを入れます。
     * 
     * @param cardId 挿入カード番号
     * @param cardData 挿入カードの詳細情報
     */
    public void insertAddressCard(Integer cardId, AddressCardData cardData){
        cards.put(cardId, cardData);
    }
}
