/**
 * 
 */
package com.cybozu.garoon3.address;

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.HashMap;
import java.util.Map;
import java.util.Vector;

import com.cybozu.garoon3.usecase.util.CSVUtil;

/**
 * アドレスカードの詳細を格納するクラスです。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AddressCardData {
    private static AddressCardFormat cardFormat= new AddressCardFormat();
    private Map <String, String> cardData = new HashMap<String, String>();
    
    /**
     * アドレスカードの項目を設定します。
     * 
     * @param argCardFormat アドレスカードの項目フォーマット
     */
    public static void setAddressCardFormat(AddressCardFormat argCardFormat){
        cardFormat = argCardFormat;
    }
    
    /**
     * アドレスカードの一つ項目に情報を設定します。
     * 
     * @param codeName 項目のコード
     * @param data 項目のデータ
     */
    public void setCardData(String codeName, String data){
        if (cardFormat.getAttribution(codeName) == null){
            AddressCardAttribution attr = new AddressCardAttribution(codeName, codeName);
            cardFormat.addAttribution(codeName, attr);
        }
        
        cardData.put(codeName, data);
    }
    
    /**
     * アドレスカードの情報をコンソールに出力します。デバッグ用の関数です。
     */
    public void printCardDetails(){
        for (Map.Entry<String, AddressCardAttribution> e : cardFormat.getAttributions().entrySet()) {
            AddressCardAttribution attr = e.getValue();
            String codeName = attr.getCodeName();
            String displayName = attr.getDisplayName();
            String str = cardData.get(codeName);
            
            if (str == null)
            	continue;
            System.out.println(displayName + " = " + str);
        }
    }
    
    /**
     * アドレスカードの項目リストを CSV ファイルに出力します
     * @param writer 出力ファイルの writer
     */
    public static void printCardFormatToCSV(OutputStreamWriter writer) {
        Vector<String> fields = cardFormat.getAttrOrder();
        int count = fields.size();
        try {
            for (int i = 0; i < count; i++){
                String attr_key = fields.elementAt(i);
                AddressCardAttribution attr = cardFormat.getAttribution(attr_key);
                if (i > 0) 
                    writer.write(", " + CSVUtil.escape(attr.getDisplayName()));
                else
                    writer.write(CSVUtil.escape(attr.getDisplayName()));
            }
            writer.write("\n");
            writer.flush();
        }
        catch (IOException e){
            return;
        }
        /*
        int count = 0;
        for (Map.Entry<Integer, String> e : cardFormat.getAttrOrder().entrySet()) {
            AddressCardAttribution attr = cardFormat.getAttribution(e.getValue());

            if (count > 0) 
                writer.write(", " + CSVUtil.escape(attr.getDisplayName()));
            else
                writer.write(CSVUtil.escape(attr.getDisplayName()));
            count++;
        }
        writer.write("\n");
        writer.flush();
        */
    }
    
    /**
     * アドレスカードの項目リストを CSV ファイルに出力します
     */
    public static void printCardFormat() {
        Vector<String> fields = cardFormat.getAttrOrder();
        int count = fields.size();
        for (int i = 0; i < count; i++){
            String attr_key = fields.elementAt(i);
            AddressCardAttribution attr = cardFormat.getAttribution(attr_key);
            System.out.print(attr_key);
            if (i > 0) 
                System.out.print(", " + attr_key + ":" + CSVUtil.escape(attr.getDisplayName()));
            else
                System.out.print(attr_key + ":" + CSVUtil.escape(attr.getDisplayName()));
        }
        /*
        int count = 0;
        for (Map.Entry<Integer, String> e : cardFormat.getAttrOrder().entrySet()) {
            String key = e.getValue();
            AddressCardAttribution attr = cardFormat.getAttribution(key);
            System.out.print(e.getKey());
            if (count > 0) 
                System.out.print(", " + key + ":" + CSVUtil.escape(attr.getDisplayName()));
            else
                System.out.print(key + ":" + CSVUtil.escape(attr.getDisplayName()));
            count++;
        }
        System.out.println("");
        */
    }
    
    /**
     * アドレスカードの情報を CSV ファイルに出力します
     * @param writer 出力ファイルの writer
     */
    public void printCardToCSV(OutputStreamWriter writer){
        Vector<String> fields = cardFormat.getAttrOrder();
        int count = fields.size();
        try {
            for (int i = 0; i < count; i++){
                String attr_key = fields.elementAt(i);
                AddressCardAttribution attr = cardFormat.getAttribution(attr_key);
                String str = cardData.get(attr.getCodeName());
                if (str == null)
                    str = "";
                if (i > 0)
                    writer.write(", " + CSVUtil.escape(str));
                else
                    writer.write(CSVUtil.escape(str));
            }
                
            writer.write("\n");
            writer.flush();
        }
        catch (IOException e){
            return;
        }
    }
}
