/**
 * 
 */
package com.cybozu.garoon3.address;

import java.util.HashMap;
import java.util.Map;
import java.util.Vector;

/**
 * アドレスカードの項目リストを管理するクラスです。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AddressCardFormat {
    private Map<String, AddressCardAttribution> attributions = new HashMap<String, AddressCardAttribution>();
    //private Map<Integer, String> attrOrder = new HashMap<Integer, String>();
    private Vector<String> attrOrder = new Vector<String>();

    /**
     * カードの項目リストを取得します。
     * 
     * @return 項目詳細のリスト
     */
    public Map<String, AddressCardAttribution> getAttributions() {
		return attributions;
	}

    /**
     * カードの項目リストを設定します。
     * 
     * @param attributions 項目詳細のリスト
     */
	public void setAttributions(Map<String, AddressCardAttribution> attributions) {
		this.attributions = attributions;
	}

	/**
	 * カードに項目の並んでいる順番を取得します。
	 * 
	 * @return 項目名が並んでいる順リスト
	 */
	public Vector<String> getAttrOrder() {
		return attrOrder;
	}

	/**
     * カードの項目を追加します。
     * 
     * @param key 項目のコードキー
     * @param attr 項目の詳細（表示名など）
     */
    public void addAttribution(String key, AddressCardAttribution attr){
    	this.attributions.put(key, attr);
        this.attrOrder.add(key);
        //numAttributions++;
    }
    
    /**
     * 項目セットを追加する
     * 
     * @param mergedFormat 項目セット
     */
    public void merge(AddressCardFormat mergedFormat){
        for (Map.Entry<String, AddressCardAttribution> e : mergedFormat.attributions.entrySet()){
            this.attributions.put(e.getKey(), e.getValue());
            this.attrOrder.add(e.getKey());
        }
    }
    
    /**
     * コードキーでカードの項目を取得します。
     * 
     * @param key コードキー
     * @return 項目の詳細
     */
    public AddressCardAttribution getAttribution(String key){
        return this.attributions.get(key);
    }
    
    /**
     * カードの項目リストをコンソールに表示します。
     */
    public void printCardFormat(){
        for (Map.Entry<String, AddressCardAttribution> e : this.attributions.entrySet()){
            AddressCardAttribution attr = e.getValue();
            System.out.println(e.getKey() + " = " + attr.getDisplayName());
        }
    }
}
