package com.cybozu.garoon3.admin;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import com.cybozu.garoon3.common.APIType;
import com.cybozu.garoon3.common.Action;

/**
 * ユーザーIDを元にログイン名と表示名の取得を行います。<br />
 * 返される結果は、取得したユーザーの情報と件数です。<br />
 * <br />
 * 指定したユーザーIDに紐づくユーザーが存在しない場合は
 * 情報の取得は行われません。<br />
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AdminGetUserDetailByIds implements Action {
    private List<Integer> userIdList = new ArrayList<Integer>();
    
    @Override
    public String getActionName() {
        return "AdminGetUserDetailByIds";
    }

    @Override
    public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (Integer userId : this.userIdList) {
            OMElement user = omFactory.createOMElement("userId", null);
            user.setText( userId.toString() );
            parameters.addChild(user);
        }
        return parameters;
    }

    /**
     * ユーザーIDを追加する
     * @param userId ユーザーID
     */
    public void addUserID(int userId)
    {
        this.userIdList.add( userId );
    }

    @Override
    public APIType getAPIType() {
        return APIType.ADMIN;
    }
}
