package com.cybozu.garoon3.admin;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import com.cybozu.garoon3.common.APIType;
import com.cybozu.garoon3.common.Action;

/**
 * ユーザーIDリストを取得するクラスです。<br />
 * <br />
 * このクラスはユーザーIDのみしか取得しません。<br />
 * ユーザーID以外の情報を取得するには、
 * com.cybozu.garoon3.admin.AdminGetUserDetailByIds を利用する必要があります。
 *
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AdminGetUserIds implements Action {

    private int offset = 0;
    private int limit  = Integer.MAX_VALUE;
    
    @Override
    public String getActionName() {
        return "AdminGetUserIds";
    }

    @Override
    public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        OMElement offsetNode = omFactory.createOMElement("offset", null);
        offsetNode.setText( String.valueOf(offset) );
        
        OMElement limitNode = omFactory.createOMElement("limit", null);
        limitNode.setText( String.valueOf(limit) );
        
        parameters.addChild( offsetNode );
        parameters.addChild( limitNode );
        return parameters;
    }

    /**
     * 取得するユーザーIDリストのオフセットを設定します。
     * 先頭は0で、負の値を指定することはできません。
     * 
     * @param offset オフセット
     */
    public void setOffset(int offset)
    {
        this.offset = offset;
    }
    
    /**
     * 取得するユーザーIDリストの個数の上限値を設定します。
     * 負の値を指定した場合は全件取得されます。
     * 
     * @param limit 上限値
     */
    public void setLimit(int limit)
    {
        this.limit = limit;
    }
    
    @Override
    public APIType getAPIType() {
        return APIType.ADMIN;
    }
}
