package com.cybozu.garoon3.admin;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import com.cybozu.garoon3.common.APIType;
import com.cybozu.garoon3.common.Action;

/**
 * ユーザー情報の変更を行うクラスです。<br />
 * 指定されたユーザーIDと紐づくユーザーに対して
 * ログイン名、表示名、パスワードの変更を行うことができます。<br />
 * 紐づくユーザーが存在しない場合はエラー(GRN_SYSAPI_64008)が返されます。<br />
 * <br />
 * 一度に変更できるユーザーは一人です。<br />
 * 複数人の情報を変更する場合は複数回このクラスを用いた操作を行う必要があります。<br />
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AdminModifyUserAccount implements Action {

    private int userId;
    private String loginName = null;
    private String displayName = null;
    private String password = null;

    /**
     * 更新するログイン名を設定します。
     * @param loginName ログイン名
     */
    public void setLoginName(String loginName) { 
    	this.loginName = loginName; 
    }
    
    /**
     * 更新する表示名を設定します。
     * @param displayName 表示名
     */
    public void setDisplayName(String displayName) { 
    	this.displayName = displayName; 
    }
    
    /**
     * 更新するパスワードを設定します。
     * @param password パスワード
     */
    public void setPassword(String password) { 
    	this.password = password;
    }
    
    /**
     * 更新対象のユーザーIDを指定します。
     * @param userId ユーザーID
     */
    public AdminModifyUserAccount(int userId)
    {
        this.userId = userId;
    }
    
    @Override
    public String getActionName() {
        return "AdminModifyUserAccount";
    }

    @Override
    public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        OMElement userIdNode = omFactory.createOMElement("userId", null);
        userIdNode.setText( String.valueOf(this.userId) );
        parameters.addChild( userIdNode );
        
        if(this.loginName != null)
        {
            OMElement loginNameNode = omFactory.createOMElement("login_name", null);
            loginNameNode.setText( this.loginName );
            parameters.addChild( loginNameNode );
        }
        
        if(this.displayName != null)
        {
            OMElement displayNameNode = omFactory.createOMElement("display_name", null);
            displayNameNode.setText( this.displayName );
            parameters.addChild( displayNameNode );
        }

        if( this.password != null)
        {
            OMElement passwordNode = omFactory.createOMElement("password_raw", null);
            passwordNode.setText( this.password );
            parameters.addChild( passwordNode );
        }
        
        return parameters;
    }
    
    @Override
    public APIType getAPIType() {
        return APIType.ADMIN;
    }
}
