package com.cybozu.garoon3.admin;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import com.cybozu.garoon3.common.APIType;
import com.cybozu.garoon3.common.Action;

/**
 * ユーザーの削除を行います。<br />
 * 削除後にユーザーの状態を元に戻す事はできません。<br />
 * <br />
 * 返される結果には、削除したユーザーIDに加え、削除したユーザーの件数が含まれます。<br />
 * 存在しないユーザーIDを指定した場合、値は無視されます。<br />
 *
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AdminRemoveUsersByIds implements Action {
    private List<Integer> userIdList = new ArrayList<Integer>();

    @Override
    public String getActionName() {
        return "AdminRemoveUsersByIds";
    }

    @Override
    public APIType getAPIType() {
        return APIType.ADMIN;
    }

    @Override
    public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (Integer userId : this.userIdList) {
            OMElement user = omFactory.createOMElement("userId", null);
            user.setText( userId.toString() );
            parameters.addChild(user);
        }
        return parameters;
    }

    /**
     * 削除するユーザーを追加する
     * @param userId ユーザーID
     */
    public void addUserID(int userId)
    {
        this.userIdList.add( userId );
    }
}
