package com.cybozu.garoon3.message;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

/**
 * メッセージの宛先を表すクラスです。<br />
 * message.xsd の ThreadType の addressee 要素を表します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class Addressee {
    private final int userId;
    private final String name;
    private boolean deleted;
    private boolean confirmed;

    /**
     * コンストラクタ
     * @param userId 宛先ユーザーID
     * @param name 宛先ユーザー名
     */
    public Addressee(int userId, String name){
        this.userId = userId;
        this.name = name;
    }
    /**
     * コンストラクタ
     * @param userId 宛先ユーザーID
     * @param name 宛先ユーザー名
     * @param confirmed 閲覧状況
     */
    public Addressee(int userId, String name, boolean confirmed){
        this.userId = userId;
        this.name = name;
        this.confirmed = confirmed;
    }
    /**
     * コンストラクタ
     * @param userId 宛先ユーザーID
     * @param name 宛先ユーザー名
     * @param deleted 宛先ユーザーの削除フラグ
     * @param confirmed 宛先ユーザーの確認状況
     */
    public Addressee(int userId, String name, boolean deleted,
            boolean confirmed) {
        this.userId = userId;
        this.name = name;
        this.deleted = deleted;
        this.confirmed = confirmed;
    }

    /**
     * 宛先ユーザーのIDを取得します。
     * @return
     */
    public int getId() {
        return this.userId;
    }

    /**
     * メッセージの宛先要素を表すOMElementインスタンスを取得します。
     * @return OMElementインスタンス
     */
    public OMElement toOMElement(){
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement addressee = omFactory.createOMElement("addressee", null);
        addressee.addAttribute("user_id", String.valueOf(this.userId), null);
        addressee.addAttribute("name", this.name, null);
        addressee.addAttribute("deleted", String.valueOf(this.deleted), null);
        addressee.addAttribute("confirmed", String.valueOf(this.confirmed), null);

        return addressee;
    }
}
