package com.cybozu.garoon3.message;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

/**
 * 添付ファイルの情報を表すクラスです。<br />
 * message.xsd の file 要素を表します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class AttachedFile {
    private final int id;
    private final String name;
    private int size;
    private String mimeType;

    /**
     * コンストラクタ
     * @param id ファイルID
     * @param name ファイル名
     */
    public AttachedFile(int id, String name){
        this.id = id;
        this.name = name;
    }
    /**
     * コンストラクタ
     * @param id ファイルID
     * @param name ファイル名
     * @param size ファイルサイズ
     * @param mimeType MIMEタイプ
     */
    public AttachedFile(int id, String name, int size, String mimeType) {
        this.id = id;
        this.name = name;
        this.size = size;
        this.mimeType = mimeType;
    }

    /**
     * 添付ファイルを表すOMElementインスタンスを取得します。
     * @return OMElementインスタンス
     */
    public OMElement toOMElement(){
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement file = omFactory.createOMElement("file", null);

        file.addAttribute("id", String.valueOf(this.id), null);
        file.addAttribute("name", this.name, null);
        if(this.size > 0){
            file.addAttribute("size", String.valueOf(this.size), null);
        }
        if(this.mimeType != null){
            file.addAttribute("mime_type", this.mimeType, null);
        }

        return file;
    }
}
