package com.cybozu.garoon3.message;

import java.util.HashMap;
import java.util.Map;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

/**
 * フォローを表すクラスです。<br />
 * message.wsdl の MessageAddFollowType を表します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class Follow {
    private final int threadId;
    private final FollowType follow;
    private final Map<Integer, String> fileMap = new HashMap<Integer, String>();
    private int fileId = 1;

    /**
     * コンストラクタ
     * @param threadId メッセージID
     * @param text フォロー内容
     */
    public Follow(int threadId, String text) {
        this.threadId = threadId;
        this.follow = new FollowType(text);
    }
    /**
     * コンストラクタ
     * @param threadId メッセージID
     * @param text フォロー内容
     * @param htmlText 書式編集を使用したフォロー内容
     */
    public Follow(int threadId, String text, String htmlText) {
        this.threadId = threadId;
        this.follow = new FollowType(text, htmlText);
    }

    /**
     * フォローに添付するファイルを追加します。
     * @param name ファイル名
     * @param content ファイルの内容(Base64binary)
     */
    public void addFile(String name, String content){
        this.fileMap.put(this.fileId, content);

        AttachedFile file = new AttachedFile(this.fileId, name);
        this.follow.addFile(file);

        this.fileId++;
    }

    /**
     * フォローを表すOMElementインスタンスを取得します。
     * @return OMElementインスタンス
     */
    public OMElement toOMElement(){
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement element = omFactory.createOMElement("add_follow", null);

        element.addChild(this.follow.toOMElement());
        for(Map.Entry<Integer, String> e : this.fileMap.entrySet()){
            OMElement file = omFactory.createOMElement("file", null);
            file.addAttribute("id", String.valueOf(e.getKey()), null);
            OMElement content = omFactory.createOMElement("content", null);
            content.setText(e.getValue());
            file.addChild(content);
            element.addChild(file);
        }
        element.addAttribute("thread_id", String.valueOf(this.threadId), null);

        return element;
    }
}
