package com.cybozu.garoon3.message;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import com.cybozu.garoon3.base.BaseChangeLogType;

/**
 * フォローの情報を表すクラスです。<br />
 * message.xsd の FollowType を表します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class FollowType {
    private final List<AttachedFile> fileList = new ArrayList<AttachedFile>();
    private BaseChangeLogType creator;
    private int id;
    private int number;
    private final String text;
    private String htmlText;

    /**
     * コンストラクタ
     * @param text フォロー内容
     */
    public FollowType(String text) {
        this.text = text;
    }
    /**
     * コンストラクタ
     * @param text フォロー内容
     * @param htmlText 書式編集を使用したフォロー内容
     */
    public FollowType(String text, String htmlText){
        this.text = text;
        this.htmlText = htmlText;
    }

    /**
     * コンストラクタ
     * @param id フォローID
     * @param number メッセージ内でのフォロー番号
     * @param text フォロー内容
     */
    public FollowType(int id, int number, String text) {
        this.id = id;
        this.number = number;
        this.text = text;
    }

    /**
     * コンストラクタ
     * @param id フォローID
     * @param number メッセージ内でのフォロー番号
     * @param text フォロー内容
     * @param htmlText 書式編集を使用したフォロー内容
     */
    public FollowType(int id, int number, String text, String htmlText){
        this.id = id;
        this.number = number;
        this.text = text;
        this.htmlText = htmlText;
    }

    /**
     * 添付ファイルを追加します。
     * @param file 添付ファイル
     */
    public void addFile(AttachedFile file){
        this.fileList.add(file);
    }
    /**
     * フォローの作成者情報を追加します。
     * @param creator 作成者情報
     */
    public void setCreator(BaseChangeLogType creator) {
        this.creator = creator;
    }

    /**
     * フォローIDを取得します。
     * @return
     */
    public int getId() {
        return this.id;
    }
    /**
     * フォロー内容を取得します。
     * @return
     */
    public String getText(){
        return this.text;
    }
    /**
     * フォロー番号を取得します。
     * @return
     */
    public int getNumber(){
        return this.number;
    }
    /**
     * フォローの添付ファイルのListを取得します。
     * @return
     */
    public List<AttachedFile> getAttachedFiles(){
        return this.fileList;
    }

    /**
     * フォローの情報を表すOMElementインスタンスを取得します。
     * @return OMElementインスタンス
     */
    public OMElement toOMElement(){
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement follow = omFactory.createOMElement("follow", null);

        for(AttachedFile file : this.fileList){
            follow.addChild(file.toOMElement());
        }
        if(this.creator != null){
            follow.addChild(this.creator.toOMElement());
        }
        follow.addAttribute("id", String.valueOf(this.id), null);
        follow.addAttribute("number", String.valueOf(this.number), null);
        follow.addAttribute("text", this.text, null);
        if(this.htmlText != null){
            follow.addAttribute("html_text", this.htmlText, null);
        }

        return follow;
    }
}
