package com.cybozu.garoon3.message;

import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.axis2.AxisFault;

import com.cybozu.garoon3.common.APIType;
import com.cybozu.garoon3.common.Action;
import com.cybozu.garoon3.common.CBServiceClient;

/**
 * メッセージのフォローを取得します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class MessageGetFollows implements Action{
    private final int threadId;
    private final int offset;
    private final int limit;

    /**
     * コンストラクタ
     * @param threadId メッセージID
     * @param offset フォロー取得開始位置
     * @param limit フォロー取得上限
     */
    public MessageGetFollows(int threadId, int offset, int limit){
        this.threadId = threadId;
        this.offset = offset;
        this.limit = limit;
    }

    @Override
    public APIType getAPIType() {
        return APIType.MESSAGE;
    }

    @Override
    public String getActionName() {
        return "MessageGetFollows";
    }

    @Override
    public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        parameters.addAttribute("thread_id", String.valueOf(this.threadId), null);
        parameters.addAttribute("offset", String.valueOf(this.offset), null);
        parameters.addAttribute("limit", String.valueOf(this.limit), null);

        return parameters;
    }

    /**
     * APIと通信してフォローを取得し、レスポンスとして取得したフォローの情報を返します。
     * @param cbServiceClient APIクライアント
     * @return フォロー情報のList
     * @throws AxisFault
     */
    public List<FollowType> sendReceive(CBServiceClient cbServiceClient) throws AxisFault{
        return MessageResponseUtil.getFollowList(cbServiceClient.sendReceive(this));
    }
}
