package com.cybozu.garoon3.message;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.axis2.AxisFault;

import com.cybozu.garoon3.common.APIType;
import com.cybozu.garoon3.common.Action;
import com.cybozu.garoon3.common.CBServiceClient;

/**
 * フォローを削除します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class MessageRemoveFollows implements Action{
    private final List<Integer> idList = new ArrayList<Integer>();

    /**
     * 削除するフォローのIDを追加します。
     * @param id フォローID
     */
    public void addId(int id){
        this.idList.add(id);
    }

    @Override
    public APIType getAPIType() {
        return APIType.MESSAGE;
    }

    @Override
    public String getActionName() {
        return "MessageRemoveFollows";
    }

    @Override
    public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for(Integer id : this.idList){
            OMElement followId = omFactory.createOMElement("follow_id", null);
            followId.setText(String.valueOf(id));
            parameters.addChild(followId);
        }

        return parameters;
    }

    /**
     * APIと通信してフォローを削除します。
     * @param cbServiceClient APIクライアント
     * @throws AxisFault
     */
    public void sendReceive(CBServiceClient cbServiceClient) throws AxisFault{
        cbServiceClient.sendReceive(this);
    }
}
