package com.cybozu.garoon3.message;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.apache.axiom.om.OMElement;
import org.apache.axis2.util.XMLUtils;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import com.cybozu.garoon3.base.BaseChangeLogType;
import com.cybozu.garoon3.util.DateUtil;

/**
 * メッセージAPIで取得したレスポンスから情報を取得するユーティリティです。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class MessageResponseUtil {
    /**
     * レスポンスからメッセージIDを取得します。
     * @param response
     * @return メッセージIDリスト
     */
    public static List<Integer> getThreadIdList(OMElement response){
        List<Integer> threadIdList = new ArrayList<Integer>();
        Element dom;

        try {
            dom = XMLUtils.toDOM(response);
        } catch (Exception e) {
            return threadIdList;
        }

        NodeList threadList = dom.getElementsByTagNameNS("*", "thread");
        for(int i=0; i<threadList.getLength(); i++){
            Element thread = (Element) threadList.item(i);
            threadIdList.add(Integer.valueOf(thread.getAttribute("id")));
        }

        return threadIdList;
    }

    /**
     * レスポンスからフォローIDを取得します。
     * @param response
     * @return フォローIDリスト
     */
    public static List<Integer> getFollowIdList(OMElement response){
        List<Integer> followIdList = new ArrayList<Integer>();
        Element dom;

        try {
            dom = XMLUtils.toDOM(response);
        } catch (Exception e) {
            return followIdList;
        }

        NodeList followList = dom.getElementsByTagNameNS("*", "follow");
        for(int i=0; i<followList.getLength(); i++){
            Element thread = (Element) followList.item(i);
            followIdList.add(Integer.valueOf(thread.getAttribute("id")));
        }

        return followIdList;
    }

    /**
     * レスポンスからフォロー情報を取得します。
     * @param response
     * @return フォロー情報のリスト
     */
    public static List<FollowType> getFollowList(OMElement response){
        List<FollowType> followList = new ArrayList<FollowType>();
        Element dom;

        try {
            dom = XMLUtils.toDOM(response);
        } catch (Exception e) {
            return followList;
        }

        NodeList followNodeList = dom.getElementsByTagNameNS("*", "follow");
        for(int i=0; i<followNodeList.getLength(); i++){
            Element follow = (Element) followNodeList.item(i);
            FollowType followType = parseFollow(follow);

            followList.add(followType);
        }

        return followList;
    }

    /**
     * レスポンスから掲示板IDを取得します。
     * @param response
     * @return 掲示板IDリスト
     */
    public static List<ThreadType> getThreadList(OMElement response){
        List<ThreadType> threadList = new ArrayList<ThreadType>();
        Element dom;

        try {
            dom = XMLUtils.toDOM(response);
        } catch (Exception e) {
            return threadList;
        }

        NodeList threadNodeList = dom.getElementsByTagNameNS("*", "thread");
        for(int i=0; i<threadNodeList.getLength(); i++){
            Element thread = (Element) threadNodeList.item(i);
            ThreadType threadType = parseThread(thread);

            threadList.add(threadType);
        }

        return threadList;
    }

    private static ThreadType parseThread(Element thread) {
        ThreadType threadType = parseThreadAttributes(thread);

        NodeList addresseeList = thread.getElementsByTagNameNS("*", "addressee");
        for(int i=0; i<addresseeList.getLength(); i++){
            Element addresseeElement = (Element) addresseeList.item(i);
            threadType.addAddressee(parseAddressee(addresseeElement));
        }

        Element content = (Element) thread.getElementsByTagNameNS("*", "content").item(0);
        String body = content.getAttribute("body");
        threadType.setBody(body);
        if( content.hasAttribute("html_body") ){
            String htmlBody = content.getAttribute("html_body");
            threadType.setHTMLBody(htmlBody);
        }

        NodeList fileList = content.getElementsByTagNameNS("*", "file");
        for(int i=0; i<fileList.getLength(); i++){
            Element file = (Element) fileList.item(i);
            threadType.addFile(parseFile(file));
        }

        NodeList followList = thread.getElementsByTagNameNS("*", "follow");
        for(int i=0; i<followList.getLength(); i++){
            Element follow = (Element) followList.item(i);
            int followId = Integer.valueOf(follow.getAttribute("id"));
            int number = Integer.valueOf(follow.getAttribute("number"));
            threadType.addFollow(followId, number);
        }

        NodeList folderList = thread.getElementsByTagNameNS("*", "folder");
        for(int i=0; i<folderList.getLength(); i++){
            Element folder = (Element) folderList.item(i);
            int folderId = Integer.valueOf(folder.getAttribute("id"));
            threadType.addFolder(folderId);
        }

        threadType.setCreator(parseBaseChangeLogType(thread, "creator"));
        threadType.setModifier(parseBaseChangeLogType(thread, "modifier"));

        return threadType;
    }

    private static ThreadType parseThreadAttributes(Element thread) {
        int id = Integer.valueOf(thread.getAttribute("id"));
        int version = Integer.valueOf(thread.getAttribute("version"));
        boolean confirm = Boolean.valueOf(thread.getAttribute("confirm"));
        String subject = thread.getAttribute("subject");
        ThreadType threadType = new ThreadType(id, version, confirm, subject);
        if( thread.hasAttribute("is_draft") ){
            boolean isDraft = Boolean.valueOf(thread.getAttribute("is_draft"));
            threadType.setIsDraft(isDraft);
        }
        if( thread.hasAttribute("snapshot") ){
            try {
                Date snapshot = DateUtil.stringToDate(thread.getAttribute("snapshot"));
                threadType.setSnapshot(snapshot);
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }

        return threadType;
    }

    private static Addressee parseAddressee(Element addresseeElement) {
        int userId = Integer.valueOf(addresseeElement.getAttribute("user_id"));
        String name = addresseeElement.getAttribute("name");
        boolean deleted = Boolean.valueOf(addresseeElement.getAttribute("deleted"));
        boolean confirmed = Boolean.valueOf(addresseeElement.getAttribute("confirmed"));

        Addressee addressee = new Addressee(userId, name, deleted, confirmed);

        return addressee;
    }

    private static FollowType parseFollow(Element follow){
        int id = Integer.valueOf(follow.getAttribute("id"));
        int number = Integer.valueOf(follow.getAttribute("number"));
        String text = follow.getAttribute("text");

        FollowType followType;
        if( follow.hasAttribute("html_text")){
            String htmlText = follow.getAttribute("html_text");
            followType = new FollowType(id, number, text, htmlText);
        }
        else{
            followType = new FollowType(id, number, text);
        }

        NodeList files = follow.getElementsByTagNameNS("*", "file");
        for(int i=0; i<files.getLength(); i++){
            Element fileElement = (Element) files.item(i);
            followType.addFile(parseFile(fileElement));
        }

        followType.setCreator(parseBaseChangeLogType(follow, "creator"));

        return followType;
    }

    private static AttachedFile parseFile(Element fileElement){
        int fileId = Integer.valueOf(fileElement.getAttribute("id"));
        String name = fileElement.getAttribute("name");
        int size = Integer.valueOf(fileElement.getAttribute("size"));
        String mimeType = fileElement.getAttribute("mime_type");

        AttachedFile file = new AttachedFile(fileId, name, size, mimeType);

        return file;
    }

    private static BaseChangeLogType parseBaseChangeLogType(Element src, String elemName){
        Element element = (Element) src.getElementsByTagNameNS("*", elemName).item(0);
        int userId = Integer.valueOf(element.getAttribute("user_id"));
        String name = element.getAttribute("name");
        Date date = null;
        try {
            date = DateUtil.stringToDate(element.getAttribute("date"));
        } catch (ParseException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        BaseChangeLogType log = new BaseChangeLogType(elemName, userId, name, date);

        return log;
    }
}
