package com.cybozu.garoon3.message;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

/**
 * メッセージを表すクラスです。<br />
 * message.wsdl の MessageCreateThreadType を表します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class Thread {
    private final ThreadType thread = new ThreadType();
    private int draftId;
    private final Map<Integer, String> fileMap = new HashMap<Integer, String>();
    private final List<Integer> removeFileIdList = new ArrayList<Integer>();
    private int fileId = 1;

    /**
     * メッセージIDを指定します。
     * @param id メッセージID
     */
    public void setId(int id) {
        this.thread.setId(id);
    }

    /**
     * 標題を設定します。
     * @param subject 標題
     */
    public void setSubject(String subject){
        this.thread.setSubject(subject);
    }

    /**
     * 閲覧状況を確認するか設定します。
     * @param confirm 閲覧状況を確認するか(true:確認する false:確認しない)
     */
    public void setConfirm(boolean confirm){
        this.thread.setConfirm(confirm);
    }

    /**
     * 宛先を追加します。
     * @param userId ユーザーID
     */
    public void addAddressee(int userId) {
        Addressee addressee = new Addressee(userId, "dummy");
        this.thread.addAddressee(addressee);
    }

    /**
     * 本文を設定します。
     * @param body メッセージ本文
     */
    public void setContent(String body){
        this.thread.setBody(body);
    }
    /**
     * 書式編集を使用して本文を設定します。
     * @param body メッセージ本文
     * @param htmlBody 書式編集を使用したメッセージ本文
     */
    public void setContent(String body, String htmlBody){
        this.thread.setBody(body);
        this.thread.setHTMLBody(htmlBody);
    }

    /**
     * 下書きIDを指定します。
     * @param draftId 下書きID
     */
    public void setDraftId(int draftId){
        this.draftId = draftId;
    }

    /**
     * 本文の添付ファイルを追加します。
     * @param name ファイル名
     * @param content ファイルの内容(Base64binary)
     */
    public void addFile(String name, String content){
        this.fileMap.put(this.fileId, content);

        AttachedFile file = new AttachedFile(this.fileId, name);
        this.thread.addFile(file);

        this.fileId++;
    }

    /**
     * 削除する添付ファイルのIDを追加します。
     * メッセージ変更時に使用します。
     * @param id ファイルID
     */
    public void addRemoveFileId(int id){
        this.removeFileIdList.add(id);
    }

    /**
     * メッセージが存在するフォルダのIDを追加します。
     * @param id フォルダID
     */
    public void addFolder(int id){
        this.thread.addFolder(id);
    }


    /**
     * メッセージを表すOMElementインスタンスを取得します。
     * @param name OMElementの要素名
     * @return OMElementインスタンス
     */
    public OMElement toOMElement(String name){
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement createThread = omFactory.createOMElement(name, null);
        OMElement thread = this.thread.toOMElement("thread");
        createThread.addChild(thread);

        if(this.draftId != 0){
            createThread.addAttribute("draft_id", String.valueOf(this.draftId), null);
        }

        for(Map.Entry<Integer, String> e : this.fileMap.entrySet()){
            OMElement file = omFactory.createOMElement("file", null);
            file.addAttribute("id", String.valueOf(e.getKey()), null);
            OMElement content = omFactory.createOMElement("content", null);
            content.setText(e.getValue());
            file.addChild(content);
            createThread.addChild(file);
        }

        for(Integer id : this.removeFileIdList){
            OMElement removeFileId = omFactory.createOMElement("remove_file_id", null);
            removeFileId.setText(String.valueOf(id));
            createThread.addChild(removeFileId);
        }

        return createThread;
    }
}
