package com.cybozu.garoon3.message;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

/**
 * メッセージの本文を表すクラスです。<br />
 * message.xsd の content 要素を表します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class ThreadContent {
    private String body;
    private String htmlBody = null;
    private final List<AttachedFile> fileList = new ArrayList<AttachedFile>();

    /**
     * 本文を設定します。
     * @param body メッセージ本文
     */
    public void setBody(String body){
        this.body = body;
    }

    /**
     * 書式編集を使用して本文を設定します。
     * @param htmlBody 書式編集を使用したメッセージ本文
     */
    public void setHTMLBody(String htmlBody){
        this.htmlBody = htmlBody;
    }

    /**
     * メッセージ本文に添付ファイルを追加します。
     * @param file 添付ファイル
     */
    public void addFile(AttachedFile file){
        this.fileList.add(file);
    }

    /**
     * メッセージの本文を取得します。
     * @return
     */
    public String getBody() {
        return this.body;
    }

    /**
     * メッセージの本文要素を表すOMElementインスタンスを取得します。
     * @return OMElementインスタンス
     */
    public OMElement toOMElement(){
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement content = omFactory.createOMElement("content", null);

        content.addAttribute("body", this.body, null);
        if(this.htmlBody != null){
            content.addAttribute("html_body", this.htmlBody, null);
        }
        for(AttachedFile file : this.fileList){
            OMElement fileElement = file.toOMElement();
            content.addChild(fileElement);
        }

        return content;
    }
}
