/**
 * 
 */
package com.cybozu.garoon3.usecase;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.List;

import org.apache.axiom.om.OMElement;
import org.apache.commons.cli.MissingArgumentException;
import org.apache.commons.cli.ParseException;

import com.cybozu.garoon3.address.AddressBook;
import com.cybozu.garoon3.address.AddressCardData;
import com.cybozu.garoon3.address.AddressCardFormat;
import com.cybozu.garoon3.address.AddressGetPersonalBookVersions;
import com.cybozu.garoon3.address.AddressGetPersonalBooksById;
import com.cybozu.garoon3.address.AddressGetPersonalCardsById;
import com.cybozu.garoon3.address.AddressUtility;
import com.cybozu.garoon3.common.CBServiceClient;
import com.cybozu.garoon3.common.Config;
import com.cybozu.garoon3.usecase.util.OptionsParser;

/**
 * API の使用例で、個人のアドレス帳を取得します。
 * 
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class GetPersonalBook {
    /**
     * コンソール実行の入口関数
     * 
     * @param args コンソールのパラメータ
     * @throws IOException ファイル入出力の例外
     * @throws MissingArgumentException パラメータの例外
     * @throws ParseException 引数にエラーがある場合
     */
    public static void main(String[] args) throws MissingArgumentException, IOException, ParseException {
        // Get options from the command line
        OptionsParser parser = new OptionsParser(args);
        if( !parser.hasOutputFileName() )
            throw new MissingArgumentException("Missing -o option");
        
        if( !parser.hasAccountFileName() )
            throw new MissingArgumentException("Missing -g option");

        // load config
        Config conf = new Config( parser.getAccountFileName() );

        CBServiceClient cbServiceClient = new CBServiceClient();
        cbServiceClient.load(conf);

        // Get the personal address bookId of current user
        AddressGetPersonalBookVersions getPersonalBookVersion = new AddressGetPersonalBookVersions();
        OMElement personal_book_version = cbServiceClient.sendReceive(getPersonalBookVersion);
        
        List<Integer> bookIds = AddressUtility.getPersonalAddressBook(personal_book_version);
        
        AddressGetPersonalBooksById getBookAction = new AddressGetPersonalBooksById();
        for ( Integer bookId : bookIds ) {
            getBookAction.addBookId(bookId);
        }

        // Get address cards in these personal books
        System.out.println("Retrieve cardIds in personal address books...");
        OMElement result = cbServiceClient.sendReceive(getBookAction);

        List<Integer> cardIds = AddressUtility.getCardIdsFromXML(result, "AddressGetPersonalBooksByIdResponse");
        AddressBook book = new AddressBook(cardIds);

        if (cardIds.isEmpty()){
            System.out.println("There are not any cards to retrieve. Exit the program.");
            System.exit(0);
        }
        
        // Get card format
        AddressCardFormat card_format = AddressUtility.getCardFormatFromXML(result, "AddressGetPersonalBooksByIdResponse");
        if (card_format == null){
            System.out.println("This personal address book does not exist. Exit the program.");
            System.exit(0);
        }
        AddressCardData.setAddressCardFormat(card_format);
        
        // Get address cards
        System.out.println("Retrieve address cards...");
        AddressGetPersonalCardsById getCardAction = new AddressGetPersonalCardsById();
        
        for ( Integer cardId : cardIds ) {
            getCardAction.addCardId(cardId);
            //System.out.println("cardId = " + cardId.toString());
        }
        
        result = cbServiceClient.sendReceive(getCardAction);
        AddressUtility.getCardDataFromXMLToBook(result, book, "AddressGetPersonalCardsByIdResponse");
        
        System.out.println("Export address data to the output file...");
        File f=new File( parser.getOutputFileName() );
        FileOutputStream fop=new FileOutputStream(f);
        //add_book.printCardsToCSV(new OutputStreamWriter(System.out));
        book.printCardsToCSV(new OutputStreamWriter(fop));
        
        cbServiceClient.cleanupTransport();
        System.out.println("Succeeded");
    }
}
