/**
 * 
 */
package com.cybozu.garoon3.usecase;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.List;

import org.apache.axiom.om.OMElement;
import org.apache.commons.cli.MissingArgumentException;
import org.apache.commons.cli.ParseException;

import com.cybozu.garoon3.address.AddressBook;
import com.cybozu.garoon3.address.AddressCardData;
import com.cybozu.garoon3.address.AddressCardFormat;
import com.cybozu.garoon3.address.AddressGetSharedBooksById;
import com.cybozu.garoon3.address.AddressGetSharedCardsById;
import com.cybozu.garoon3.address.AddressUtility;
import com.cybozu.garoon3.common.CBServiceClient;
import com.cybozu.garoon3.common.Config;
import com.cybozu.garoon3.usecase.util.OptionsParser;

/**
 * API の使用例で、共有アドレス帳を取得します。
 *
 * @author $api_author Garoon Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class GetSharedBook {
    
	/**
     * 
     * コンソール実行の入口関数
     * 
     * @param args コンソールのパラメータ
     * @throws IOException ファイル入出力の例外
     * @throws MissingArgumentException パラメータの例外
     * @throws ParseException 引数にエラーがある場合
     */
    public static void main(String[] args) throws MissingArgumentException, IOException, ParseException {
     // Get options from the command line
        OptionsParser parser = new OptionsParser(args);
        if( !parser.hasOutputFileName() )
            throw new MissingArgumentException("Missing -o option");
        
        if( !parser.hasInputFileName() )
            throw new MissingArgumentException("Missing -i option");
        
        if( !parser.hasAccountFileName() )
            throw new MissingArgumentException("Missing -g option");
        
        // load config
        Config conf = new Config( parser.getAccountFileName() );

        CBServiceClient cbServiceClient = new CBServiceClient();
        cbServiceClient.load(conf);

        // Get a list of shared bookIds
        System.out.println("Get a list of shared books from the input file...");
        List<Integer> bookIds = AddressUtility.getIDList(parser.getInputFileName(), "book_id");
        
        System.out.println("Retrieve address cards in each shared book ...");        
        for(Integer bookId : bookIds)
        {
            AddressBook book = new AddressBook();      
            // Get cardIds inside this shared book        
            System.out.println("Retrieve cardIds in shared book " + bookId);
            
            AddressGetSharedBooksById action = new AddressGetSharedBooksById();
            action.addBookId(bookId);
            OMElement result = cbServiceClient.sendReceive(action);

            AddressCardFormat cardFormat = AddressUtility.getCardFormatFromXML(result, "AddressGetSharedBooksByIdResponse");
            if (cardFormat == null){
                System.out.println("This shared address book either does not exist or is not accessible from your account. Skip it.");
                continue;
            }
            AddressCardData.setAddressCardFormat(cardFormat);
            //AddressCardData.printCardFormat();
            
            List<Integer> cardIds = AddressUtility.getCardIdsFromXML(result, "AddressGetSharedBooksByIdResponse");
            if (cardIds.isEmpty()) continue;
            
            book.addCardIds(cardIds);
	        AddressGetSharedCardsById getCardAction = new AddressGetSharedCardsById();
	        getCardAction.setBookId(bookId);
	        for( Integer cardId : cardIds ) {
	            getCardAction.addCardId(cardId);
	        }
	        
	        result = cbServiceClient.sendReceive(getCardAction);
	        AddressUtility.getCardDataFromXMLToBook(result, book, "AddressGetSharedCardsByIdResponse");
	        System.out.println("Export address data of book " + bookId + " to the output file...");
	        File f = new File( parser.getOutputFileName() + "_" + bookId + ".csv" );
	        FileOutputStream fop = new FileOutputStream(f);
	        book.printCardsToCSV(new OutputStreamWriter(fop));
        }
        
        cbServiceClient.cleanupTransport();
        System.out.println("Succeeded");
    }
}
